evaluate_sparse_b1_multilinear_native

Function evaluate_sparse_b1_multilinear_native 

pub fn evaluate_sparse_b1_multilinear_native<F: Field>(
    bits: &SparseBitVector,
    point: &[F],
) -> F
Evaluates the multilinear extension of a bit vector natively in the field F.

Produces the identical result to evaluate_sparse_b1_multilinear, but multiplies each set bit’s last lookup unreduced with WideMul and reduces the sum once, which the generic path cannot since E: FieldOps does not imply it.

Preconditions

  • point.len() must equal bits.log_len()